package Task::Tags;

# Pragmas.
use strict;
use warnings;

# Version.
our $VERSION = 0.03;

1;

__END__

=pod

=encoding utf8

=head1 NAME

Task::Tags - Install the Tags modules.

=head1 SYNOPSIS

 cpanm Task::Tags

=head1 SEE ALSO

L<Tags>,
L<Tags::Element>,
L<Tags::Output::Indent>,
L<Tags::Output::PYX>,
L<Tags::Output::Structure>.

=head1 REPOSITORY

L<https://github.com/tupinek/Task-Tags>

=head1 AUTHOR

Michal Špaček L<mailto:skim@cpan.org>

L<http://skim.cz>

=head1 LICENSE AND COPYRIGHT

 © 2015 Michal Špaček
 Artistic License
 BSD 2-Clause License

=head1 VERSION

0.03

=cut
